<?php
if ( version_compare( $GLOBALS['wp_version'], '4.1', '<' ) ) {

	function amber_wp_title( $title, $sep ) {
		if ( is_feed() ) {
			return $title;
		}

		global $page, $paged;

		$title .= get_bloginfo( 'name', 'display' );

		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title .= " $sep $site_description";
		}

		if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
			$title .= " $sep " . sprintf( __( 'Page %s', 'amber' ), max( $paged, $page ) );
		}

		return $title;
	}
	add_filter( 'wp_title', 'amber_wp_title', 10, 2 );

	function amber_render_title() {
		?>
		<title><?php wp_title( '|', true, 'right' ); ?></title>
	<?php
	}
	add_action( 'wp_head', 'amber_render_title' );
}

function stm_breadcrumbs() {
	$page_for_posts = get_option('page_for_posts');
	echo '<ol class="breadcrumb">';
	if( is_single() ) {
		echo '<li><a href="'. esc_url(home_url()) .'">'.__( 'Home', 'amber' ).'</a></li>';
		if($page_for_posts) {
			echo '<li><a href="'.get_permalink($page_for_posts).'">'.__( 'Blog', 'amber' ).'</a></li>';
		} else {
			echo '<li><a href="'. esc_url(home_url()) .'">'.__( 'Blog', 'amber' ).'</a></li>';
		}
		echo '<li>'.get_the_title().'</li>';
	}
	if(is_page()) {
		echo '<li><a href="'. esc_url(home_url()) .'">'.__( 'Home', 'amber' ).'</a></li>';
		echo '<li>'.get_the_title().'</li>';
	}
	if(is_archive()) {
		echo '<li><a href="'. esc_url(home_url()) .'">'.__( 'Home', 'amber' ).'</a></li>';
		echo '<li>'.get_the_archive_title().'</li>';
	}
	if(is_home()){
		echo '<li><a href="'. esc_url(home_url()) .'">'.__( 'Home', 'amber' ).'</a></li>';
		if($page_for_posts) {
			echo '<li>'.get_the_title($page_for_posts).'</li>';
		} else {
			echo '<li>'.__( 'Blog', 'amber' ).'</li>';
		}
	}
	echo '</ol>';
}

class Bootstrap_walker extends Walker_Nav_Menu {

	function start_el(&$output, $object, $depth = 0, $args = Array(), $current_object_id = 0){

		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$class_names = $value = '';

		// If the item has children, add the dropdown class for bootstrap
		if ( $args->has_children ) {
			$class_names = "dropdown ";
		}

		$classes = empty( $object->classes ) ? array() : (array) $object->classes;

		$class_names .= join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $object ) );
		$class_names = ' class="'. esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $object->ID . '"' . $value . $class_names .'>';

		$attributes  = ! empty( $object->attr_title ) ? ' title="'  . esc_attr( $object->attr_title ) .'"' : '';
		$attributes .= ! empty( $object->target )     ? ' target="' . esc_attr( $object->target     ) .'"' : '';
		$attributes .= ! empty( $object->xfn )        ? ' rel="'    . esc_attr( $object->xfn        ) .'"' : '';
		$attributes .= ! empty( $object->url )        ? ' href="'   . esc_attr( $object->url        ) .'"' : '';

		// if the item has children add these two attributes to the anchor tag
		if ( $args->has_children ) {
			$attributes .= ' class="dropdown-toggle"';

		}

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>';
		$item_output .= $args->link_before .apply_filters( 'the_title', $object->title, $object->ID );
		$item_output .= $args->link_after;

		// if the item has children add the caret just before closing the anchor tag
		if ( $args->has_children ) {
			$item_output .= '</a><b class="caret"></b>';
		}
		else {
			$item_output .= '</a>';
		}

		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $object, $depth, $args );
	} // end start_el function

	function start_lvl(&$output, $depth = 0, $args = Array()) {
		$indent = str_repeat("\t", $depth);
		$output .= "\n$indent<ul class=\"dropdown-menu\">\n";
	}

	function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ){
		$id_field = $this->db_fields['id'];
		if ( is_object( $args[0] ) ) {
			$args[0]->has_children = ! empty( $children_elements[$element->$id_field] );
		}
		return parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
	}
}

// Custom Comment Form
function stm_comment_form($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
	?>
	<<?php echo esc_attr( $tag ) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
	<?php if ( 'div' != $args['style'] ) : ?>
		<div id="div-comment-<?php comment_ID() ?>" class="comment-body">
	<?php endif; ?>
	<div class="comment-author avatar">
		<?php echo get_avatar( $comment, 70 ); ?>
	</div>
	<div class="comment-data">
	<div class="comment-meta">
		<div class="comment-author vcard">
			<?php printf( __( '<span class="fn">%s</span>' ), get_comment_author_link() ); ?>
		</div>
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'amber' ); ?></em>
			<br />
		<?php endif; ?>
		<div class="comment-metadata">
			<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
				<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s at %2$s', 'amber' ), get_comment_date(),  get_comment_time() ); ?></a>
			<?php edit_comment_link( __( '(Edit)', 'amber' ), '  ', '' ); ?>
		</div>
		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			<i class="fa fa-reply"></i>
		</div>
	</div>

	<?php comment_text(); ?>
	</div>

	<?php if ( 'div' != $args['style'] ) : ?>
		</div>
	<?php endif; ?>
<?php
}

// Svg mimes
function stm_svg_mime($mimes) {
	$mimes['svg'] = 'image/svg+xml';
	return $mimes;
}
add_filter('upload_mimes', 'stm_svg_mime');

// Add Event
if(!empty($_REQUEST['event_add'])) {
	$event_id = intval($_REQUEST['event_id']);
	$json['result'] = true;

	$members = get_post_meta($event_id, 'event_members', true);
	$members = intval($members);
	update_post_meta($event_id, 'event_members', $members+1);

	$json['total_members'] = get_post_meta($event_id, 'event_members', true);

	echo json_encode($json);

	exit;
}

// Javascript Variables
add_action( 'wp_head', 'stm_ajaxurl' );

function stm_ajaxurl() {
	?>
	<script type="text/javascript">
		var ajaxurl = '<?php echo esc_url( admin_url('admin-ajax.php') ); ?>';
		var postTitle = '<?php echo get_the_title(get_the_ID()); ?>';
	</script>
<?php
}

// Mailchimp
function function_stm_subscribe() {

	$json = array();
	$email = urldecode(filter_input(INPUT_POST, 'email', FILTER_SANITIZE_EMAIL));

	if(!filter_var($email, FILTER_VALIDATE_EMAIL)){
		$json['error'] = __('Enter a valid email', 'amber');
		echo json_encode($json);
		exit;
	}else{
		require_once("mailchimp/Handling.class.php");
		Handling::handling_request_with_confirmation($email, NULL);
	}
}

add_action('wp_ajax_stm_subscribe', 'function_stm_subscribe');
add_action('wp_ajax_nopriv_stm_subscribe', 'function_stm_subscribe');

// Post Class
function stm_post_classes( $classes ) {
	global $post;
	if(has_post_thumbnail()) {
		$classes[] = 'has-thumbnail';
	}
	return $classes;
}
add_filter( 'post_class', 'stm_post_classes' );

// STM Skin Layer Slider
if( class_exists('LS_Sources') ) {
	LS_Sources::addSkins( get_template_directory().'/inc/ls-skins' );
}

// Custom post tags
function add_custom_types_to_tax( $query ) {
	if( is_category() || is_tag() && empty( $query->query_vars['suppress_filters'] ) ) {

// Get all your post types
		$post_types = get_post_types();

		$query->set( 'post_type', $post_types );
		return $query;
	}
}

if( ! is_admin() ){
    add_filter( 'pre_get_posts', 'add_custom_types_to_tax' );
}


// Excerpt
function stm_excerpt_length( $length ) {
	return 20;
}
add_filter( 'excerpt_length', 'stm_excerpt_length', 999 );

function new_excerpt_more( $more ) {
	return '...';
}
add_filter('excerpt_more', 'new_excerpt_more');

/**
 * Favicon
 */
function favicon_link() {
    if ( $favicon = get_theme_mod( 'favicon' ) ) {
        echo '<link rel="shortcut icon" type="image/x-icon" href="' . esc_url( $favicon ) . '" />' . "\n";
    } elseif( $favicon = stm_option( 'favicon', false, 'url' ) )  {
		echo '<link rel="shortcut icon" type="image/x-icon" href="' . esc_url( $favicon ) . '" />' . "\n";
    } else {
		echo '<link rel="shortcut icon" type="image/x-icon" href="' . get_template_directory_uri() . '/inc/assets/images/icons/favicon.png" />' . "\n";
	}
}

add_action( 'wp_head', 'favicon_link' );

// Layer slider import
add_filter('layerslider_installed', 'stm_layerslider_demos');

function stm_layerslider_demos() {
	include LS_ROOT_PATH.'/classes/class.ls.importutil.php';
	new LS_ImportUtil(get_template_directory().'/inc/demo/data/layer_slider.zip');
}

// Body class

add_filter( 'body_class', 'stm_body_classes' );
function stm_body_classes( $classes ) {
	if( is_home() ) {
		$page_ID = get_option('page_for_posts');
	} elseif ( function_exists( 'is_shop' ) && is_shop() ) {
		$page_ID = get_option( 'woocommerce_shop_page_id' );
	} else {
		$page_ID = get_the_ID();
	}
	if( get_post_type() == 'post' ) {
		$outer_title = get_post_meta( $page_ID, 'header_post_title', true );
	} else {
		$outer_title = get_post_meta( $page_ID, 'page_title', true );
	}

	if( $outer_title == 'hide' ) {
		$classes[] = 'outer-title_hide';
	}

	return $classes;
}


function stm_print_styles() {
	$primary_color = stm_option('primary_color');
	$mobile_menu_item_border_bot_color = stm_option('mobile_menu_item_border_bot_color');
	$mobile_menu_typography = stm_option('mobile_menu_typography');
	$custom_css = '';

	if( !empty( $primary_color ) ) {
		$custom_css .= "body .ult-carousel-wrapper.bullets-white .slick-dots li.slick-active i {\n";
		$custom_css .= "\tcolor:" . $primary_color . " !important;\n";
		$custom_css .= "}\n\n";
	}
	if( !empty( $mobile_menu_item_border_bot_color ) ) {
		$custom_css .= "@media (max-width: 991px) {\n";
		if( !empty( $mobile_menu_item_border_bot_color ) ) {
			$custom_css .= "\t.main-navbar .navbar-nav > li > a:hover,\n";
			$custom_css .= "\t.main-navbar .navbar-nav > li > a:focus,\n";
			$custom_css .= "\t.main-navbar .navbar-nav > li > a {\n";
			$custom_css .= "\t\tborder-bottom-color: " . $mobile_menu_item_border_bot_color . "\n";
			$custom_css .= "\t}\n\n";
		}
		if( !empty( $mobile_menu_typography ) ) {
			$custom_css .= "\t.main-navbar .navbar-nav > li > a,\n";
			$custom_css .= "\t.main-navbar .dropdown-menu > li > a {\n";
			$custom_css .= "\t\tfont-size: " . $mobile_menu_typography['font-size'] . " !important\n";
			$custom_css .= "\t}\n";
			$custom_css .= "}\n";
		}
	}


	if( !empty( $custom_css ) ) {
		wp_add_inline_style( 'amber-style', $custom_css );
	}

}
add_action( 'wp_enqueue_scripts', 'stm_print_styles' );

function stm_custom_css() {
 $site_css = stm_option( 'site_css' );
 $output   = "\n<style id=\"stm_custom_css\" type=\"text/css\">\n" . preg_replace( '/\s+/', ' ', $site_css ) . "\n</style>\n";
 if ( ! empty( $site_css ) ) {
  echo $output;
 }
}

add_action( 'wp_head', 'stm_custom_css' );