<?php

class STM_VC_Info_Box {

	function __construct() {
		add_action( 'init', array( $this, 'integrateWithVC' ) );
		add_shortcode( 'stm_info_box', array( $this, 'render' ) );
	}

	public function integrateWithVC() {
		if ( function_exists( 'vc_map' ) ) {

            $icons_array = file( get_template_directory() . '/inc/assets/icons/stm_icons.json' );
            $icons_array = json_decode( implode( '', $icons_array ), true );
            $icons = array();

            foreach( $icons_array['icons'] as $val ){
                $icons[] .= $val['properties']['name'];
            }

			vc_map( array(
				'name'        => __( 'Info Box', 'amber' ),
				'base'        => 'stm_info_box',
				'category'    => __( 'STM', 'amber' ),
				'params'      => array(
					array(
						"type" => "attach_image",
						"class" => "",
						"heading" => __("Upload Image:", 'amber' ),
						"param_name" => "image",
						"value" => "",
					),
					array(
						"type" => "number",
						"class" => "",
						"heading" => __("Image Width", 'amber' ),
						"param_name" => "image_width",
						"value" => 30,
						"min" => 16,
						"max" => 512,
						"suffix" => "px",
					),
					array(
						'type' => 'textfield',
						'class' => '',
						'holder' => 'div',
						'heading' => __( 'Title', 'amber' ),
						'param_name' => 'title'
					),
					array(
						'type' => 'textarea_html',
						'class' => '',
						'heading' => __( 'Text', 'amber' ),
						'param_name' => 'content'
					),
					array(
						'type' => 'dropdown',
						'heading' => "Tag",
						'param_name' => 'tag',
						'value' => array( "h1", "h2", "h3", "h4", "h5", "h6" ),
						'group' => 'Typography'
					),
                    array(
                        'type' => 'dropdown',
                        'heading' => "Icons",
                        'param_name' => 'stm_icons',
                        'value' => $icons,
                        'group' => 'Typography'
                    ),
					array(
						'type' => 'colorpicker',
						'heading' => "Separator",
						'param_name' => 'separator_color',
						'value' => "",
					),
					array(
						'type' => 'colorpicker',
						'heading' => "Separator fill",
						'param_name' => 'separator_fill_color',
						'value' => "",
					),
					array(
						'type' => 'dropdown',
						'heading' => "Style",
						'param_name' => 'info_box_styles',
						'value' => array(
							__( 'Default', 'amber' ) => '',
							__( 'Box', 'amber' ) => ' box',
						),
					),
				)
			) );
		}
	}


	public function render( $atts, $content = null ) {

		$title = $tag = $image = $image_width = $separator_color = $separator_fill_color = $info_box_styles = '';

		extract( shortcode_atts( array(
			'title' => '',
			'tag' => 'h4',
			'image' => '',
			'image_width' => '',
			'separator_color' => '',
			'separator_fill_color' => '',
			'info_box_styles' => '',
		), $atts ) );

		$output = '';
		$image_css = '';
		if($image_width != '') {
			$image_css .= 'font-size:'.$image_width.'px';
		}
		$output .= '<div class="info_box'.$info_box_styles.'">';
		$img = wp_get_attachment_image_src( $image, 'full');
		if($img[0]) {
			if($image_css != '') {
				$output .= '<div class="info-box_img" style="'.$image_css.'"><img src="'.esc_url($img[0]).'" alt="'.$title.'" /></div>';
			} else {
				$output .= '<div class="info-box_img"><img src="'.esc_url($img[0]).'" alt="'.$title.'" /></div>';
			}
		}
		if ( $title ) {
			$output .= '<'.$tag.'>' . $title . '</'.$tag.'>';
		}
		if($info_box_styles != ' box') {
			if($separator_color != '') {
				$output .= '<div class="info-box_separator" style="background-color:'.$separator_color.';">';
			} else {
				$output .= '<div class="info-box_separator">';
			}
			if($separator_fill_color != '') {
				$output .= '<div class="line" style="background-color:'.$separator_fill_color.';"></div>';
			} else {
				$output .= '<div class="line"></div>';
			}

			$output .= '</div>';
		}
		$output .= wpb_js_remove_wpautop( $content, true );
		$output .= '</div>';

		return $output;
	}

}

if( defined( 'WPB_VC_VERSION' ) ){
	new STM_VC_Info_Box();
}