<?php

if (!defined('ABSPATH')) die('-1');

class STM_VC_Rental_Services {
	function __construct() {
		// We safely integrate with VC with this hook
		add_action( 'init', array( $this, 'integrateWithVC' ) );

		// Use this when creating a shortcode addon
		add_shortcode( 'stm_rental_services', array( $this, 'render' ) );
	}

	public function integrateWithVC() {
		// Check if Visual Composer is installed
		if ( ! defined( 'WPB_VC_VERSION' ) ) {
			return;
		}
		if(function_exists("vc_map")) {
			vc_map(array(
				"name" => __("Rental Services", 'amber'),
				"base" => "stm_rental_services",
				"class" => "stm_rental_services",
				"controls" => "full",
				"category" => __('STM', 'amber'),
				"params" => array(
					array(
						"type" => "textfield",
						"class" => "",
						"heading" => __("Title", 'amber'),
						"param_name" => "title",
						"holder" => 'div',
						"value" => "",
					),
					array(
						'type' => 'dropdown',
						'heading' => "Style",
						'param_name' => 'view_style',
						'value' => array(
							__( 'Default', 'amber' ) => '',
							__( 'No Caption', 'amber' ) => 'no_caption',
						),
					),
				)
			));
		}
	}

	/*
	Shortcode logic how it should be rendered
	*/
	public function render( $atts, $content = null ) {
		$title = $view_style = '';

		extract( shortcode_atts( array(
			'title' => '',
			'view_style' => '',
		), $atts ) );

		$output = '';
		$args = array(
			'post_type' => 'rental_service',
			'posts_per_page' => -1,
		);

		$posts = get_posts( $args );

		$output .= '<div class="rental-service_latest js-carousel">';

			foreach($posts as $post ) {
				// Currency
				$rental_service_price_currency = get_post_meta( $post->ID, 'rental_service_price_currency', true );
				$rental_service_price_currency_position = get_post_meta( $post->ID, 'rental_service_price_currency_position', true );

				// Price A
				$rental_service_price_label_a = get_post_meta( $post->ID, 'rental_service_price_label_a', true );
				$rental_service_cost_a = get_post_meta( $post->ID, 'rental_service_cost_a', true );

				// Image
				$rental_service_image_id = get_post_thumbnail_id($post->ID);
				$rental_service_image = wp_get_attachment_image_src($rental_service_image_id, 'full');

				$output .= '<div class="rental-service_item">';
				$output .= '<div class="rs-item_inner">';
				$output .= '<div class="rs-item_actions">';
				$output .= '<a class="rs-item_action_zoom js-fancybox" href="'. esc_url($rental_service_image[0]) .'"><i class="fa fa-search-plus"></i></a>';
				$output .= '<a class="rs-item_action_link" href="'. get_permalink($post->ID) .'"><i class="fa fa-eye"></i></a>';
				$output .= '</div>';
				$output .= '<div class="rs-item_content">'. get_the_post_thumbnail($post->ID, 'full') .'</div>';
				if( $view_style != 'no_caption' ) {
					$output .= '<div class="rs-item_caption">';
					$output .= '<div class="rs-item_title">'. get_the_title($post->ID) .'</div>';
					$output .= '<div class="rs-item_price">'. $rental_service_price_currency .' '. $rental_service_cost_a .' '. $rental_service_price_label_a .'</div>';
					$output .= '</div>';
				}
				$output .= '</div>';
				$output .= '</div>';
			}
		$output .= '</div>';

		return $output;
	}
}

new STM_VC_Rental_Services();
