<?php

if (!defined('ABSPATH')) die('-1');

class STM_VC_Staff_Member {
	function __construct() {
		// We safely integrate with VC with this hook
		add_action( 'init', array( $this, 'integrateWithVC' ) );

		// Use this when creating a shortcode addon
		add_shortcode( 'stm_staff_member', array( $this, 'render' ) );
	}

	public function integrateWithVC() {
		// Check if Visual Composer is installed
		if ( ! defined( 'WPB_VC_VERSION' ) ) {
			return;
		}
		if(function_exists("vc_map")) {
			vc_map(array(
				"name" => __("Staff Member", 'amber'),
				"base" => "stm_staff_member",
				"class" => "stm_staff_member",
				"controls" => "full",
				"category" => __('STM', 'amber'),
				"params" => array(
					array(
						"type" => "attach_image",
						"class" => "",
						"heading" => __("Photo", 'amber'),
						"param_name" => "stm_staff_member_photo",
						"value" => "",
					),
					array(
						"type" => "number",
						"class" => "",
						"heading" => __("Height", 'amber'),
						"param_name" => "stm_staff_member_photo_height",
						"value" => "",
					),
					array(
						"type" => "textfield",
						"class" => "",
						"heading" => __("Name", 'amber'),
						"param_name" => "stm_staff_member_name",
						"value" => "",
						"holder" => "div",
					),
					array(
						"type" => "textfield",
						"class" => "",
						"heading" => __("Job", 'amber'),
						"param_name" => "stm_staff_member_job",
						"value" => "",
					),
					array(
						"type" => "textarea_html",
						"class" => "",
						"heading" => __("Details", 'amber'),
						"param_name" => "content",
					),
					array(
						"type" => "textfield",
						"class" => "",
						"heading" => __("Button text", 'amber'),
						"param_name" => "stm_staff_member_btn",
						"value" => "",
					),
					array(
						"type" => "vc_link",
						"class" => "",
						"heading" => __("Link", 'amber'),
						"param_name" => "stm_staff_member_link",
						"value" => "",
					),
					array(
						'type' => 'colorpicker',
						'heading' => "Name Color",
						'param_name' => 'name_color',
						'value' => "",
						'group' => 'Typography'
					),
					array(
						'type' => 'textfield',
						'heading' => "Name Size",
						'param_name' => 'name_size',
						'value' => "",
						'group' => 'Typography'
					),
					array(
						'type' => 'colorpicker',
						'heading' => "Job Color",
						'param_name' => 'job_color',
						'value' => "",
						'group' => 'Typography'
					),
					array(
						'type' => 'textfield',
						'heading' => "Job Size",
						'param_name' => 'job_size',
						'value' => "",
						'group' => 'Typography'
					),
					array(
						'type' => 'colorpicker',
						'heading' => "Description Color",
						'param_name' => 'description_color',
						'value' => "",
						'group' => 'Typography'
					),
					array(
						'type' => 'textfield',
						'heading' => "Description Size",
						'param_name' => 'description_size',
						'value' => "",
						'group' => 'Typography'
					),
				)
			));
		}
	}

	// Shortcode logic how it should be rendered
	public function render( $atts, $content = null ) {
		$stm_staff_member_photo = $stm_staff_member_name = $stm_staff_member_job = $stm_staff_member_link = $stm_staff_member_photo_height = $stm_staff_member_btn = $name_color = $name_size = $job_color = $job_size = $description_size = $description_color = '';

		extract( shortcode_atts( array(
			'stm_staff_member_photo' => '',
			'stm_staff_member_name' => '',
			'stm_staff_member_job' => '',
			'stm_staff_member_link' => '',
			'stm_staff_member_photo_height' => '',
			'stm_staff_member_btn' => '',
			'name_color' => '',
			'name_size' => '',
			'job_color' => '',
			'job_size' => '',
			'description_size' => '',
			'description_color' => ''
		), $atts ) );

		$stm_staff_member_photo = wp_get_attachment_image_src($stm_staff_member_photo, 'full');
		$stm_staff_member_link = vc_build_link($stm_staff_member_link);
		$name_css = $job_css = $description_css = '';

		if($name_color != '') {
			$name_css .= 'color:'.$name_color.';';
		}
		if($name_size != '') {
			$name_css .= 'font-size:'.$name_size.';';
		}

		if($job_color != '') {
			$job_css .= 'color:'.$job_color.';';
		}
		if($job_size != '') {
			$job_css .= 'font-size:'.$job_size.';';
		}

		if($description_color != '') {
			$description_css .= 'color:'.$description_color.';';
		}
		if($description_size != '') {
			$description_css .= 'font-size:'.$description_size.';';
		}

		$output = '';

		$output .= '<div class="stm_staff-member">';
		$output .= '<div class="stm_member-data">';
		$output .= '<div class="stm_member_photo" style="background-image: url('.$stm_staff_member_photo[0].'); width: 100%; height: '.$stm_staff_member_photo_height.'px"></div>';
		$output .= '<div class="stm_member_summary">';
		$output .= '<div class="stm_summary_above">';
		if($name_css != '') {
			$output .= '<div class="stm_member_name" style="'.$name_css.'">'. $stm_staff_member_name .'</div>';
		} else {
			$output .= '<div class="stm_member_name">'. $stm_staff_member_name .'</div>';
		}

		if($job_css != '') {
			$output .= '<div class="stm_member_job" style="'.$job_css.'">'. $stm_staff_member_job .'</div>';
		} else {
			$output .= '<div class="stm_member_job">'. $stm_staff_member_job .'</div>';
		}
		$output .= '</div>';
		if($description_css != '') {
			$output .= '<div class="stm_summary_details" style="'.$description_css.'">';
		} else {
			$output .= '<div class="stm_summary_details">';
		}
			$output .=  wpb_js_remove_wpautop( $content, true );
			$output .= '</div>';

		$output .= '<div class="stm_member_bottom">';
		$output .= '<a class="stm_details_more" href="' .$stm_staff_member_link['url']. '" title="'. $stm_staff_member_link['title'] .'"><span class="stm_details-more_text">'. $stm_staff_member_btn .'</span><span class="stm_details-more_hover"></span></a>';
		$output .= '</div>';
		$output .= '</div>';
		$output .= '</div>';
		$output .= '</div>';

		return $output;
	}
}

new STM_VC_Staff_Member();
