<?php
class STM_Widget_Banner extends WP_Widget {
	function __construct() {
		parent::__construct(
			'banner',
			__('Banner', 'amber'),
			array( 'description' => __( 'Upload you banner', 'amber' ), )
		);
	}

	public function widget( $args, $instance ) {
		echo $args['before_widget'];
		$image_src = wp_get_attachment_image($instance[ 'image_uri' ], 'full');
		echo balanceTags( $image_src, true );
		echo $args['after_widget'];
	}

	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		} else {
			$title = __( 'Banner', 'amber' );
		}
		if( isset( $instance[ 'image_uri' ] ) ) {
			$image_uri = wp_get_attachment_image_src($instance[ 'image_uri' ], 'full');
			$image_uri = $image_uri[0];
		} else {
			$image_uri = '';
		}

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Widget Title', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $title ); ?>"/>
		</p>

			<div class="stm-banner-image" style="margin-bottom: 10px">
				<div class="image-preview-wrap" style="margin-bottom: 10px">
					<img class="image-preview" style="display: block; height: auto; max-width: 100%" src="<?php echo esc_url( $image_uri ); ?>" alt=""/>
					<input class="image-uri-keep" type="hidden" name="<?php echo esc_attr( $this->get_field_name('image_uri') ); ?>" id="<?php echo esc_attr( $this->get_field_id('image_uri') ); ?>" value="<?php echo esc_url( $image_uri ); ?>"/>
				</div>
				<input type="button" class="button button-primary add-image" id="add-banner-image" value="Add"/>
			</div>

		<script type="text/javascript">
			jQuery(function($) {
				function media_upload( button_class) {
					var _custom_media = true,
						_orig_send_attachment = wp.media.editor.send.attachment,
					    imagePreview = jQuery('.stm-banner-image .image-preview'),
						keepImgUri = jQuery('.stm-banner-image .image-uri-keep');

					jQuery('body').on('click',button_class, function(e) {
						var button_id ='#'+jQuery(this).attr('id');
						var button = jQuery(button_id);
						var id = button.attr('id').replace('_button', '');
						_custom_media = true;
						wp.media.editor.send.attachment = function(props, attachment){
							if ( _custom_media  ) {
								imagePreview.attr( 'src', attachment.url );
								keepImgUri.val( attachment.id );
							} else {
								return _orig_send_attachment.apply( button_id, [props, attachment] );
							}
						}
						wp.media.editor.open(button);
						return false;
					});
				}
				media_upload( '.stm-banner-image .add-image');

			});
		</script>

	<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? $new_instance['title'] : '';
		$instance['image_uri'] = ( ! empty( $new_instance['image_uri'] ) ) ? $new_instance['image_uri'] : '';
		return $instance;
	}
}

function stm_banner_widget() {
	register_widget( 'STM_Widget_Banner' );
}
add_action( 'widgets_init', 'stm_banner_widget' );