<?php
class STM_Widget_Contact_Us extends WP_Widget {
	function __construct() {
		parent::__construct(
			'contact_us',
			__('Contact us', 'amber'),
			array( 'description' => __( 'Contacts information', 'amber' ), )
		);
	}

	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo $args['before_widget'];
		if ( ! empty( $title ) ) {
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		}

		echo '<ul class="contact-details_list left-icon">';
		echo '<li class="address">'.__('Address:', 'amber').' '. balanceTags( $instance['address'], true ).'</li>';
		echo '<li class="phone">'.__('Phone:', 'amber').' '. balanceTags( $instance['phone'], true ).'</li>';
		echo '<li class="email">'.__('E-Mail:', 'amber').' <a href="mailto:'. esc_attr( $instance['email'] ).'">'.esc_html( $instance['email'] ).'</a></li>';
		echo '</ul>';
		echo  $args['after_widget'];
	}

	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		} else {
			$title = __( 'Get in touch', 'amber' );
		}
		if ( isset( $instance[ 'address' ] ) ) {
			$address = $instance[ 'address' ];
		} else {
			$address = __( '321 Street Name, United Kingdom, London', 'amber' );
		}

		if ( isset( $instance[ 'phone' ] ) ) {
			$phone = $instance[ 'phone' ];
		} else {
			$phone = '+7 998 71 150 30 20';
		}

		if ( isset( $instance[ 'email' ] ) ) {
			$email = $instance[ 'email' ];
		} else {
			$email = 'info@stylemixthemes.net';
		}

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Widget Title', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $title ); ?>"/>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'address' ) ); ?>"><?php _e( 'Address', 'amber' ); ?></label>
			<textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'address' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'address' ) ); ?>" ><?php echo balanceTags( $address ); ?></textarea>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'phone' ) ); ?>"><?php _e( 'Phone', 'amber' ); ?></label>
			<textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'phone' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'phone' ) ); ?>" ><?php echo balanceTags( $phone ); ?></textarea>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>"><?php _e( 'E-Mail', 'amber' ); ?></label><br/>
			<textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email' ) ); ?>" ><?php echo balanceTags( $email ); ?></textarea>
		</p>
	<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? $new_instance['title'] : '';
		$instance['address'] = ( ! empty( $new_instance['address'] ) ) ? $new_instance['address'] : '';
		$instance['phone'] = ( ! empty( $new_instance['phone'] ) ) ? $new_instance['phone'] : '';
		$instance['email'] = ( ! empty( $new_instance['email'] ) ) ? $new_instance['email'] : '';
		return $instance;
	}
}

function stm_contact_us_widget() {
	register_widget( 'STM_Widget_Contact_Us' );
}
add_action( 'widgets_init', 'stm_contact_us_widget' );