<?php
/*
Plugin Name: STM Post Type
Plugin URI: http://stylemixthemes.com/
Description: STM Post Type
Author: Stylemix Themes
Author URI: http://stylemixthemes.com/
Text Domain: stm_post_type
Version: 2.1
*/

define( 'STM_POST_TYPE', 'stm_post_type' );

$plugin_path = dirname(__FILE__);

require_once $plugin_path . '/post_type.class.php';

$options = get_option('stm_post_types_options');

$defaultPostTypesOptions = array(
    'rental_service' => array(
        'title' => __( 'Rental Service', STM_POST_TYPE ),
        'plural_title' => __( 'Rental Services', STM_POST_TYPE ),
        'rewrite' => 'rental_service'
    ),
    'event' => array(
        'title' => __( 'Event', STM_POST_TYPE ),
        'plural_title' => __( 'Events', STM_POST_TYPE ),
        'rewrite' => 'event'
    ),
);

$stm_post_types_options = wp_parse_args( $options, $defaultPostTypesOptions );

// Projects
STM_PostType::registerPostType(
    'rental_service',
    $stm_post_types_options['rental_service']['title'],
    array(
        'pluralTitle' => $stm_post_types_options['rental_service']['plural_title'],
        'menu_icon' => 'dashicons-format-gallery',
        'rewrite' => array(
            'slug' => $stm_post_types_options['rental_service']['rewrite']
        ),
        'supports' => array( 'title', 'editor', 'thumbnail', 'comments' ),
    )
);

// Projects taxonomy
STM_PostType::addTaxonomy( 'rental_service_categories', __( 'Categories', STM_POST_TYPE ), 'rental_service' );
STM_PostType::addTaxonomy( 'rental_service_features', __( 'Features', STM_POST_TYPE ), 'rental_service' );

// Events
STM_PostType::registerPostType(
    'event',
    $stm_post_types_options['event']['title'],
    array(
        'pluralTitle' => $stm_post_types_options['event']['plural_title'],
        'menu_icon' => 'dashicons-calendar',
        'rewrite' => array(
            'slug' => $stm_post_types_options['event']['rewrite']
        ),
        'supports' => array( 'title', 'editor', 'thumbnail', 'comments', 'excerpt' ),
    )
);

// Events taxonomy
STM_PostType::addTaxonomy( 'event_categories', __( 'Categories', STM_POST_TYPE ), 'event' );

// Metabox
STM_PostType::addMetaBox( 'page_options', __( 'Page Options', STM_POST_TYPE ), array( 'page', 'product', 'event', 'rental_service' ), '', '', '', array(
    'fields' => array(
        'section_page_header' => array(
            'label'   => __( 'Outer Title', STM_POST_TYPE ),
            'type'    => 'separator'
        ),
        'page_title' => array(
            'label' => __( 'Show / Hide', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                ''     => __( 'Show', STM_POST_TYPE ),
                'hide' => __( 'Hide', STM_POST_TYPE ),
            )
        ),
        'page_title_bg_type' => array(
            'label' => __( 'Background', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'image' => __( 'Image', STM_POST_TYPE ),
                'color' => __( 'Color', STM_POST_TYPE ),
            )
        ),
        'page_title_bg' => array(
            'label' => __( 'Background Image', STM_POST_TYPE ),
            'type'  => 'image',
        ),
        'page_title_bg_color' => array(
            'label' => __( 'Background Color', STM_POST_TYPE ),
            'type'    => 'color_picker',
        ),
        'page_title_icon' => array(
            'label' => __( 'Icon', STM_POST_TYPE ),
            'type'  => 'image',
        ),
        'page_header_align' => array(
            'label' => __( 'Content Alignment', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                ''       => __( 'Left', STM_POST_TYPE ),
                'right'  => __( 'Right', STM_POST_TYPE ),
                'center' => __( 'Center', STM_POST_TYPE ),
            )
        ),
        'section_page_header_title' => array(
            'label'   => __( 'Outer Title - Page Title', STM_POST_TYPE ),
            'type'    => 'separator'
        ),
        'page_title_display' => array(
            'label' => __( 'Show / Hide', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                ''     => __( 'Show', STM_POST_TYPE ),
                'hide' => __( 'Hide', STM_POST_TYPE ),
            )
        ),
        'page_title_color' => array(
            'label' => __( 'Color', STM_POST_TYPE ),
            'type'    => 'color_picker',
        ),
        'page_title_transform' => array(
            'label' => __( 'Text Transform', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                ''          => __( 'Normal', STM_POST_TYPE ),
                'uppercase' => __( 'Uppercase', STM_POST_TYPE ),
            )
        ),
        'section_page_header_desc' => array(
            'label'   => __( 'Outer Title - Description', STM_POST_TYPE ),
            'type'    => 'separator'
        ),
        'page_description' => array(
            'label' => __( 'Text', STM_POST_TYPE ),
            'type'  => 'textarea',
        ),
        'page_description_color' => array(
            'label' => __( 'Color', STM_POST_TYPE ),
            'type'    => 'color_picker',
        ),
        'separator_page_layout' => array(
            'label'   => __( 'Layout', STM_POST_TYPE ),
            'type'    => 'separator'
        ),
        'page_container' => array(
            'label' => __( 'Container', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'default' => __( 'Default', STM_POST_TYPE ),
                'vc'      => __( 'Build with VC', STM_POST_TYPE ),
                'clear'      => __( 'Clear Content', STM_POST_TYPE ),
            )
        ),
        'page_sidebar' => array(
            'label' => __( 'Sidebar', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'hide'  => __( 'Hide', STM_POST_TYPE ),
                'right' => __( 'Right', STM_POST_TYPE ),
                'left'  => __( 'Left', STM_POST_TYPE ),
            )
        ),
    )
) );

STM_PostType::addMetaBox( 'post_options', __( 'Post Options', STM_POST_TYPE ), array( 'post' ), '', '', '', array(
    'fields' => array(
        'section_post_title' => array(
            'label'   => __( 'Outer Title', STM_POST_TYPE ),
            'type'    => 'separator'
        ),
        'header_post_title' => array(
            'label' => __( '( Show / Hide )', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                ''     => __( 'Show', STM_POST_TYPE ),
                'hide' => __( 'Hide', STM_POST_TYPE ),
            )
        ),
        'post_title_bg_type' => array(
            'label' => __( 'Background', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'image' => __( 'Image', STM_POST_TYPE ),
                'color' => __( 'Color', STM_POST_TYPE ),
            )
        ),
        'post_title_bg' => array(
            'label' => __( 'Background Image', STM_POST_TYPE ),
            'type'  => 'image',
        ),
        'post_title_bg_color' => array(
            'label' => __( 'Background Color', STM_POST_TYPE ),
            'type'    => 'color_picker',
        ),
        'post_title_display' => array(
            'label' => __( 'Post Title ( Show / Hide )', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                ''     => __( 'Show', STM_POST_TYPE ),
                'hide' => __( 'Hide', STM_POST_TYPE ),
            )
        ),
        'post_title_color' => array(
            'label' => __( 'Color', STM_POST_TYPE ),
            'type'    => 'color_picker',
        ),
        'post_title_transform' => array(
            'label' => __( 'Text Transform', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                ''          => __( 'Normal', STM_POST_TYPE ),
                'uppercase' => __( 'Uppercase', STM_POST_TYPE ),
            )
        ),
        'post_header_meta' => array(
            'label' => __( 'Meta ( Show / Hide )', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'show'  => __( 'Show', STM_POST_TYPE ),
                'hide'  => __( 'Hide', STM_POST_TYPE ),
            )
        ),
        'post_header_align' => array(
            'label' => __( 'Content Alignment', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                ''       => __( 'Left', STM_POST_TYPE ),
                'right'  => __( 'Right', STM_POST_TYPE ),
                'center' => __( 'Center', STM_POST_TYPE ),
            )
        ),
        'post_sidebar' => array(
            'label' => __( 'Sidebar', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'right' => __( 'Right', STM_POST_TYPE ),
                'left'  => __( 'Left', STM_POST_TYPE ),
                'hide'  => __( 'Hide', STM_POST_TYPE ),
            )
        ),
    )
) );

STM_PostType::addMetaBox( 'rental_service_images', __( 'Images', STM_POST_TYPE ), array( 'rental_service' ), '', 'side', '', array(
    'fields' => array(
        'rental_service_images' => array(
            'label' => '',
            'type'    => 'images',
        ),
    )
) );

STM_PostType::addMetaBox( 'rental_details', __( 'Details', STM_POST_TYPE ), array( 'rental_service' ), '', '', '', array(
    'fields' => array(
        'renta_service_price_a' => array(
            'label' => __( 'Price A', STM_POST_TYPE ),
            'type' => 'separator'
        ),
        'rental_service_price_label_a' => array(
            'label' => __( 'Label', STM_POST_TYPE ),
            'type'    => 'text',
        ),
        'rental_service_cost_a' => array(
            'label' => __( 'Cost', STM_POST_TYPE ),
            'type'    => 'text',
        ),
        'renta_service_price_b' => array(
            'label' => __( 'Price B', STM_POST_TYPE ),
            'type' => 'separator'
        ),
        'rental_service_price_label_b' => array(
            'label' => __( 'Label', STM_POST_TYPE ),
            'type'    => 'text',
        ),
        'rental_service_cost_b' => array(
            'label' => __( 'Cost', STM_POST_TYPE ),
            'type'    => 'text',
        ),
        'renta_service_price_options' => array(
            'label' => __( 'Price Options', STM_POST_TYPE ),
            'type' => 'separator'
        ),
        'rental_service_price_currency' => array(
            'label' => __( 'Currency', STM_POST_TYPE ),
            'type'    => 'text',
        ),
        'rental_service_price_currency_position' => array(
            'label' => __( 'Currency position', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'left'   => __( 'Left', STM_POST_TYPE ),
                'right'  => __( 'Right', STM_POST_TYPE ),
            )
        ),
    )
) );

STM_PostType::addMetaBox( 'event_details', __( 'Event Details', STM_POST_TYPE ), array( 'event' ), '', '', '', array(
    'fields' => array(
        'event_date_start' => array(
            'label' => __( 'When', STM_POST_TYPE ),
            'type'    => 'date_picker',
        ),
        'event_place' => array(
            'label' => __( 'Where', STM_POST_TYPE ),
            'type'    => 'textarea',
        ),
        'event_subject' => array(
            'label'   => __( 'Subject', STM_POST_TYPE ),
            'type'    => 'textarea'
        ),
        'event_status' => array(
            'label' => __( 'Status', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'available'   => __( 'Available', STM_POST_TYPE ),
                'cancelled'   => __( 'Cancelled', STM_POST_TYPE ),
                'full_booked' => __( 'Full Booked', STM_POST_TYPE ),
            )
        ),
        'event_map_lat' => array(
            'label'   => __( 'Latitude', STM_POST_TYPE ),
            'type'    => 'text'
        ),
        'event_map_lng' => array(
            'label'   => __( 'Longitude', STM_POST_TYPE ),
            'type'    => 'text'
        ),
        'event_map_zoom' => array(
            'label'   => __( 'Zoom', STM_POST_TYPE ),
            'type'    => 'text',
            'description' => 'Default zoom = 18',
        ),
    )
) );

STM_PostType::addMetaBox( 'event_layout', __( 'Event Layout', STM_POST_TYPE ), array( 'event' ), '', '', '', array(
    'fields' => array(
        'event_sidebar' => array(
            'label' => __( 'Siderbar', STM_POST_TYPE ),
            'type'    => 'select',
            'options' => array(
                'right' => __( 'Right', STM_POST_TYPE ),
                'left'  => __( 'Left', STM_POST_TYPE ),
                'hide'  => __( 'Hide', STM_POST_TYPE ),
            )
        ),
    )
) );

function stm_plugin_styles() {
    $plugin_url =  plugins_url('', __FILE__);

    wp_enqueue_style( 'admin-styles', $plugin_url . '/assets/css/admin.css', null, null, 'all' );

    wp_enqueue_style( 'wp-color-picker' );
    wp_enqueue_script( 'wp-color-picker');

    wp_enqueue_style( 'stmcss-datetimepicker', $plugin_url . '/assets/css/jquery.stmdatetimepicker.css', null, null, 'all' );
    wp_enqueue_script( 'stmjs-datetimepicker', $plugin_url . '/assets/js/jquery.stmdatetimepicker.js', array( 'jquery' ), null, true );

    wp_enqueue_media();
}

add_action( 'admin_enqueue_scripts', 'stm_plugin_styles' );

add_action('plugins_loaded', 'stm_plugin_setup');

function stm_plugin_setup(){

    $plugin_url =  plugins_url('', __FILE__);

    load_plugin_textdomain( 'stm_post_type', false, $plugin_url . '/languages' );

}

add_action( 'admin_menu', 'stm_register_post_types_options_menu' );

if( ! function_exists( 'stm_register_post_types_options_menu' ) ){
    function stm_register_post_types_options_menu(){
        add_submenu_page( 'tools.php', __('STM Post Types', STM_POST_TYPE), __('STM Post Types', STM_POST_TYPE), 'manage_options', 'stm_post_types', 'stm_post_types_options' );
    }
}

if( ! function_exists( 'stm_post_types_options' ) ){
    function stm_post_types_options(){

        if ( ! empty( $_POST['stm_post_types_options'] ) ) {
            update_option( 'stm_post_types_options', $_POST['stm_post_types_options'] );
        }

        $options = get_option('stm_post_types_options');

        $defaultPostTypesOptions = array(
            'rental_service' => array(
                'title' => __( 'Rental Service', STM_POST_TYPE ),
                'plural_title' => __( 'Rental Services', STM_POST_TYPE ),
                'rewrite' => 'rental_service'
            ),
            'event' => array(
                'title' => __( 'Event', STM_POST_TYPE ),
                'plural_title' => __( 'Events', STM_POST_TYPE ),
                'rewrite' => 'event'
            ),
        );

        $options = wp_parse_args( $options, $defaultPostTypesOptions );

        echo '
			<div class="wrap">
		        <h2>' . __( 'Custom Post Type Renaming Settings', STM_POST_TYPE ) . '</h2>

		        <form method="POST" action="">
		            <table class="form-table">
		                <tr valign="top">
		                    <th scope="row">
		                        <label for="rental_service_title">' . __( '"Rental Services" title (admin panel tab name)', STM_POST_TYPE ) . '</label>
		                    </th>
		                    <td>
		                        <input type="text" id="rental_service_title" name="stm_post_types_options[rental_service][title]" value="' . $options['rental_service']['title'] . '"  size="25" />
		                    </td>
		                </tr>
		                <tr valign="top">
		                    <th scope="row">
		                        <label for="rental_service_plural_title">' . __( '"Rental Services" plural title', STM_POST_TYPE ) . '</label>
		                    </th>
		                    <td>
		                        <input type="text" id="rental_service_plural_title" name="stm_post_types_options[rental_service][plural_title]" value="' . $options['rental_service']['plural_title'] . '"  size="25" />
		                    </td>
		                </tr>
		                <tr valign="top">
		                    <th scope="row">
		                        <label for="rental_service_rewrite">' . __( '"Rental Services" rewrite (URL text)', STM_POST_TYPE ) . '</label>
		                    </th>
		                    <td>
		                        <input type="text" id="rental_service_rewrite" name="stm_post_types_options[rental_service][rewrite]" value="' . $options['rental_service']['rewrite'] . '"  size="25" />
		                    </td>
		                </tr>
		                <tr valign="top"><th scope="row"></th></tr>
		                <tr valign="top">
		                    <th scope="row">
		                        <label for="events_title">' . __( '"Events" title (admin panel tab name)', STM_POST_TYPE ) . '</label>
		                    </th>
		                    <td>
		                        <input type="text" id="events_title" name="stm_post_types_options[event][title]" value="' . $options['event']['title'] . '"  size="25" />
		                    </td>
		                </tr>
		                <tr valign="top">
		                    <th scope="row">
		                        <label for="events_plural_title">' . __( '"Events" plural title', STM_POST_TYPE ) . '</label>
		                    </th>
		                    <td>
		                        <input type="text" id="events_plural_title" name="stm_post_types_options[event][plural_title]" value="' . $options['event']['plural_title'] . '"  size="25" />
		                    </td>
		                </tr>
		                <tr valign="top">
		                    <th scope="row">
		                        <label for="events_rewrite">' . __( '"Events" rewrite (URL text)', STM_POST_TYPE ) . '</label>
		                    </th>
		                    <td>
		                        <input type="text" id="events_rewrite" name="stm_post_types_options[event][rewrite]" value="' . $options['event']['rewrite'] . '"  size="25" />
		                    </td>
		                </tr>
		            </table>
		            <p>' . __( "NOTE: After you change the rewrite field values, you'll need to refresh permalinks under Settings -> Permalinks", STM_POST_TYPE ) . '</p>
		            <br/>
		            <p>
						<input type="submit" value="' . __( 'Save settings', STM_POST_TYPE ) . '" class="button-primary"/>
					</p>
		        </form>
		    </div>
		';
    }
}