<?php
global $theme_info;
$theme_info = wp_get_theme();
define('STM_THEME_VERSION', ( WP_DEBUG ) ? time() : $theme_info->get( 'Version' ));

if ( ! function_exists( 'amber_setup' ) ) {
	function amber_setup() {

		load_theme_textdomain( 'amber', get_template_directory() . '/languages' );

		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'title-tag' );

		add_theme_support( 'post-thumbnails' );

		register_nav_menus( array(
			'primary' => __( 'Primary Menu', 'amber' )
		) );

		add_theme_support( 'html5', array(
			'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
		) );

		add_theme_support( 'post-formats', array(
			'aside', 'image', 'video', 'quote', 'link',
		) );

		add_theme_support( 'woocommerce' );

	}
}
add_action( 'after_setup_theme', 'amber_setup' );

function amber_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'amber' ),
		'id'            => 'sidebar',
		'class'         => '',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s sidebar-widget">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => __( 'Event', 'amber' ),
		'id'            => 'event',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s events-widget">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => __( 'Shop', 'amber' ),
		'id'            => 'shop',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s shop-widget">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer', 'amber' ),
		'id'            => 'footer',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s col-xs-12 col-sm-6 col-md-3 col-lg-3">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'amber_widgets_init' );

function amber_scripts() {
    // Fonts
    $font_1 = get_theme_mod('font_1', 'Lora');
    if($font_1 == '') {
        $font_1 = 'Lora';
    }
    $font_2 = get_theme_mod('font_1', 'Roboto Slab');
    if($font_2 == '') {
        $font_2 = 'Roboto Slab';
    }

    $fonts_array = file( get_template_directory() . '/inc/customizer/webfonts.json' );
    $fonts_array = json_decode( implode( '', $fonts_array ), true );

    foreach ( $fonts_array['items'] as $val ) {
        if($val['family'] == $font_1) {
            $font_1_variants = implode(',', $val['variants']);
            $font_1_subsets = implode(',', $val['subsets']);
        }

        if($val['family'] == $font_2) {
            $font_2_variants = implode(',', $val['variants']);
            $font_2_subsets = implode(',', $val['subsets']);
        }
    }

    $font_1 = str_replace(' ', '+', $font_1);
    $font_2 = str_replace(' ', '+', $font_2);

	wp_register_style( 'amber-font-1', 'http://fonts.googleapis.com/css?family='.$font_1.':'.$font_1_variants.'&subset='.$font_1_subsets.'' );
	wp_register_style( 'amber-font-2', 'http://fonts.googleapis.com/css?family='.$font_2.':'.$font_2_variants.'&subset='.$font_2_subsets.'' );

	wp_enqueue_style('amber-font-1');
	wp_enqueue_style('amber-font-2');

	wp_register_style( 'normalize', get_template_directory_uri() . '/inc/assets/css/normalize.css', null, STM_THEME_VERSION, 'all' );
	wp_register_style( 'bootstrap.min', get_template_directory_uri() . '/inc/assets/css/bootstrap.min.css', null, STM_THEME_VERSION, 'all' );
	wp_register_style( 'font-awesome.min', get_template_directory_uri() . '/inc/assets/css/font-awesome.min.css', null, STM_THEME_VERSION, 'all' );
	wp_register_style( 'icomoon', get_template_directory_uri() . '/inc/assets/css/icomoon.css', null, STM_THEME_VERSION, 'all' );
	wp_register_style( 'owl-carousel', get_template_directory_uri() . '/inc/assets/css/owl.carousel.css', null, STM_THEME_VERSION, 'all' );
	wp_register_style( 'jquery-fancybox', get_template_directory_uri() . '/inc/assets/css/jquery.fancybox.css', null, STM_THEME_VERSION, 'all' );
	wp_register_style( 'stm-woocommerce', get_template_directory_uri() . '/inc/assets/css/woocommerce.css', null, STM_THEME_VERSION, 'all' );

	wp_enqueue_style( 'normalize' );
	wp_enqueue_style( 'bootstrap.min' );
	wp_enqueue_style( 'font-awesome.min' );
	wp_enqueue_style( 'icomoon' );
	wp_enqueue_style( 'owl-carousel' );
	wp_enqueue_style( 'jquery-fancybox' );
	wp_enqueue_style( 'stm-woocommerce' );
	wp_enqueue_style( 'amber-style', get_stylesheet_uri() );

	wp_register_script( 'amber-scripts', get_template_directory_uri() . '/inc/assets/js/scripts.js', 'jquery', STM_THEME_VERSION, true );
	wp_register_script( 'bootstrap', get_template_directory_uri() . '/inc/assets/js/bootstrap.min.js', 'jquery', STM_THEME_VERSION, true );
	wp_register_script( 'owl-carousel', get_template_directory_uri() . '/inc/assets/js/owl.carousel.min.js', 'jquery', STM_THEME_VERSION, true );
	wp_register_script( 'fancybox', get_template_directory_uri() . '/inc/assets/js/jquery.fancybox.js', 'jquery', STM_THEME_VERSION, true );

	/* Enqueue scripts */
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'bootstrap' );
	wp_enqueue_script( 'owl-carousel' );
	wp_enqueue_script( 'fancybox' );
	wp_enqueue_script( 'amber-scripts' );


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'amber_scripts' );

add_action( 'vc_before_init', 'amber_vcSetAsTheme' );
function amber_vcSetAsTheme() {
	vc_set_as_theme();
}

function admin_styles() {
	wp_enqueue_media();
}

add_action( 'admin_enqueue_scripts', 'admin_styles' );

if ( defined( 'WPB_VC_VERSION' ) ) {
	$dir = get_stylesheet_directory() . '/inc/visual-composer/templates'; // First, set new directory for templates
	vc_set_shortcodes_templates_dir( $dir );
}

add_image_size( 'thumb-840x500', 840, 500, true);