<?php

class STM_VC_Separator {

	function __construct() {
		add_action( 'init', array( $this, 'integrateWithVC' ) );
		add_shortcode( 'stm_separator', array( $this, 'render' ) );
	}

	public function integrateWithVC() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map( array(
				'name'     => __( 'Separator', 'amber' ),
				'base'     => 'stm_separator',
				'category' => __( 'STM', 'amber' ),
				'params'   => array(
                    array(
						'type' => 'colorpicker',
						'heading' => "Line - Color",
						'param_name' => 'color',
						'value' => "",
					),
                    array(
                        'type' => 'textfield',
                        'heading' => "Line - Height",
                        'param_name' => 'height',
                        'value' => "",
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => __( 'Icon Type:', 'amber' ),
                        'param_name' => 'icon_type',
                        'value' => array(
                            __( 'Image', 'amber' ) => 'image',
                            __( 'Font Icon', 'amber' )    => 'font_icon',
                        ),
                    ),
                    array(
                        "type" => "attach_image",
                        "class" => "",
                        "heading" => __("Image", 'amber'),
                        "param_name" => "icon",
                        "value" => "",
                        'dependency' => array('element' => 'icon_type', 'value' => 'image'),
                    ),
                    array(
                        "type" => "iconpicker",
                        "class" => "",
                        "heading" => __("Font", 'amber'),
                        "param_name" => "icon_font",
                        "value" => "",
                        'dependency' => array('element' => 'icon_type', 'value' => 'font_icon'),
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => __("Icon - Size", 'amber'),
                        'param_name' => 'icon_font_size',
                        'value' => "",
                        'dependency' => array('element' => 'icon_type', 'value' => 'font_icon'),
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => "Icon - Space (Left/Right)",
                        'param_name' => 'icon_padd',
                        'value' => "",
                    ),
				)
			) );
		}
	}


	public function render( $atts, $content = null ) {

		$color = $width = $height = $icon_type = $icon = $icon_font = $icon_el = $icon_padd = '';

		extract( shortcode_atts( array(
			'color' => '',
			'icon_type' => '',
			'icon' => '',
			'icon_font' => '',
			'icon_font_size' => '',
			'height' => '',
			'icon_padd' => '',
		), $atts ) );


        if( $icon_type == 'image' && !empty( $icon ) ) {
            $icon_el = wp_get_attachment_image( $icon, 'full' );
        }

        if( $icon_type == 'font_icon' && !empty( $icon_font ) ) {
            $icon_el = '<i class="'. $icon_font .'"></i>';
        }

        $output = '';

        $separator_css = $icon_css = '';
        $separator_styles = $icon_styles = array();

        if($height) {
            $separator_styles[] .= 'height:'.$height.'';
        }
        if($color) {
            $separator_styles[] .= 'background-color:'.$color.';';
        }

        if($separator_styles) {
            $separator_css .= 'style="'. esc_attr(implode(';', $separator_styles)) .'"';
        }

        if($icon_padd) {
            $icon_styles[] .= 'padding:0 '.$icon_padd.'';
        }

        if( !empty( $icon_font_size ) ) {
            $icon_styles[] .= 'font-size:' . $icon_font_size;
        }

        if($icon_styles) {
            $icon_css = 'style="'.esc_attr(implode(';', $icon_styles)).'"';
        }

        $output .= '<div class="stm-separator"><span class="stm-separator_holder __line"><span class="stm-separator_line" '.$separator_css.'></span></span><span class="stm-separator_holder __icon" '.$icon_css.'>'.$icon_el.'</span><span class="stm-separator_holder __line"><span class="stm-separator_line" '.$separator_css.'></span></span></div>';

		return $output;
	}

}

if( defined( 'WPB_VC_VERSION' ) ){
	new STM_VC_Separator();
}