<?php
class STM_Widget_Recent_Events extends WP_Widget {
	function __construct() {
		parent::__construct(
			'recent_events',
			__('Recent Events', 'amber'),
			array( 'description' => __( 'Recent events', 'amber' ), )
		);
	}

	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo $args['before_widget'];
		if ( ! empty( $title ) ) {
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		}

		$events = get_posts( array ( 'post_type' => 'event', 'posts_per_page' => $instance[ 'events_count' ] ) );
		echo '<ul class="recent-events_list">';
		foreach ( $events as $event ) {
			echo '<li>';
			echo '<h5><a href="'.get_the_permalink( $event->ID ).'">'.get_the_title( $event->ID ).'</a></h5>';
			echo '<table>';
			echo '<tr>';
			echo '<td><i class="fa fa-clock-o"></i></td>';
			echo '<td>'.get_post_meta( $event->ID, 'event_date_start', true ).'</td>';
			echo '</tr>';
			echo '<tr>';
			echo '<td><i class="fa fa-map-marker"></i></td>';
			echo '<td>'.get_post_meta( $event->ID, 'event_place', true ).'</td>';
			echo '</tr>';
			echo '</table>';
			echo '</li>';
		}

		echo '</ul>';
		echo $args['after_widget'];
	}

	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		} else {
			$title = __( 'Events', 'amber' );
		}
		if( isset( $instance[ 'events_count' ] ) ) {
			$events_count = $instance[ 'events_count' ];
		} else {
			$events_count = 3;
		}

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Widget Title', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $title ); ?>"/>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'events_count' ) ); ?>"><?php _e( 'Events count', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'events_count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'events_count' ) ); ?>" value="<?php echo esc_attr( $events_count ); ?>"/>
		</p>

	<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? $new_instance['title'] : '';
		$instance['events_count'] = ( !empty($new_instance['events_count'] ) ) ? $new_instance['events_count'] : '';
		return $instance;
	}
}

function stm_recent_events_widget() {
	register_widget( 'STM_Widget_Recent_Events' );
}
add_action( 'widgets_init', 'stm_recent_events_widget' );