<?php
class STM_Widget_Tweets extends WP_Widget {
	function __construct() {
		parent::__construct(
			'stm_tweets',
			__('Twitter Tweets', 'amber'),
			array( 'description' => __( 'Twitter tweets', 'amber' ), )
		);
	}

	public function widget( $args, $instance ) {
		$output = '';
		$tweets_count = $instance[ 'count_tweets' ];
		$twitter_array = get_transient( 'tweets' );

		require_once (get_template_directory() . '/inc/twitter/tmhOAuth.php');

		if(empty($twitter_array)) {
			$auth_twitter = new tmhOAuth (
				array (
				'consumer_key' => $instance['consumer_api_key'],
				'consumer_secret' => $instance['consumer_api_secret'],
				'token' => $instance['access_token'],
				'secret' => $instance['access_token_secret'],
				)
			);

			$twitter_data = $auth_twitter->request('GET', $auth_twitter->url('1.1/statuses/user_timeline'), array(
				'count' => $tweets_count,
				'include_rts' => true,
				'include_entities' => true
			));

			$data  = $auth_twitter->response['response'];

			$twitter_array = json_decode($data, true);

			set_transient('tweets', $twitter_array, 60 * 60 * $instance['refresh_cache']);
		}

		if( is_array( $twitter_array ) ) {

			$output .= '<ul class="tweets_list">';

			foreach( $twitter_array as $tweet ) {
				$tweet_date = date(get_option('date_format'), strtotime($tweet['created_at']));
				$tweet_text = $tweet['text'];

				$tweet_text = preg_replace('@(https?://([-\w\.]+)+(:\d+)?(/([\w/_\./-]*(\?\S+)?)?)?)@', '<a target="blank" title="$1" href="$1">$1</a>', $tweet_text);
				$tweet_text = preg_replace('/#([0-9a-zA-Z_-]+)/', "<a target='blank' title='$1' href=\"http://twitter.com/search?q=%23$1\">#$1</a>",  $tweet_text);
				$tweet_text = preg_replace("/@([0-9a-zA-Z_-]+)/", "<a target='blank' title='$1' href=\"http://twitter.com/$1\">@$1</a>",  $tweet_text);

				$output .= '<li class="tweet left-icon">';
				$output .= '<p>'. $tweet_text .'</p>';
				$output .=  '</li>';
			}

			$output .= '</ul>';
		}


		$title = apply_filters( 'widget_title', $instance['title'] );
		echo $args['before_widget'];
		if ( ! empty( $title ) ) {
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		}

		echo balanceTags( $output, true );

		echo $args['after_widget'];
	}

	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		} else {
			$title = __( 'Latest tweets', 'amber' );
		}
		if ( isset( $instance[ 'refresh_cache' ] ) ) {
			$refresh_cache = $instance[ 'refresh_cache' ];
		} else {
			$refresh_cache = 1;
		}
		if ( isset( $instance[ 'consumer_api_key' ] ) ) {
			$consumer_api_key = $instance[ 'consumer_api_key' ];
		} else {
			$consumer_api_key = '';
		}
		if ( isset( $instance[ 'consumer_api_secret' ] ) ) {
			$consumer_api_secret = $instance[ 'consumer_api_secret' ];
		} else {
			$consumer_api_secret = '';
		}
		if ( isset( $instance[ 'access_token' ] ) ) {
			$access_token = $instance[ 'access_token' ];
		} else {
			$access_token = '';
		}
		if ( isset( $instance[ 'access_token_secret' ] ) ) {
			$access_token_secret = $instance[ 'access_token_secret' ];
		} else {
			$access_token_secret = '';
		}
		if ( isset( $instance[ 'count_tweets' ] ) ) {
			$count_tweets = $instance[ 'count_tweets' ];
		} else {
			$count_tweets = '';
		}

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Widget Title', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $title ); ?>"/>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'refresh_cache' ) ); ?>"><?php _e( 'Refresh Cache', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'refresh_cache' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'refresh_cache' ) ); ?>" value="<?php echo esc_attr( $refresh_cache ); ?>"/>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'count_tweets' ) ); ?>"><?php _e( 'Tweets', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'count_tweets' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'count_tweets' ) ); ?>" value="<?php echo esc_attr( $count_tweets ); ?>"/>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'consumer_api_key' ) ); ?>"><?php _e( 'Consumer Api Key', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'consumer_api_key' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'consumer_api_key' ) ); ?>" value="<?php echo esc_attr( $consumer_api_key ); ?>"/>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'consumer_api_secret' ) ); ?>"><?php _e( 'Consumer Api Secret', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'consumer_api_secret' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'consumer_api_secret' ) ); ?>" value="<?php echo esc_attr( $consumer_api_secret ); ?>"/>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'access_token' ) ); ?>"><?php _e( 'Access Token', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'access_token' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'access_token' ) ); ?>" value="<?php echo esc_attr( $access_token ); ?>"/>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'access_token_secret' ) ); ?>"><?php _e( 'Access Token Secret', 'amber' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'access_token_secret' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'access_token_secret' ) ); ?>" value="<?php echo esc_attr( $access_token_secret ); ?>"/>
		</p>

	<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? $new_instance['title'] : '';
		$instance['refresh_cache'] = ( ! empty( $new_instance['refresh_cache'] ) ) ? $new_instance['refresh_cache'] : '';
		$instance['consumer_api_key'] = ( ! empty( $new_instance['consumer_api_key'] ) ) ? $new_instance['consumer_api_key'] : '';
		$instance['consumer_api_secret'] = ( ! empty( $new_instance['consumer_api_secret'] ) ) ? $new_instance['consumer_api_secret'] : '';
		$instance['access_token'] = ( ! empty( $new_instance['access_token'] ) ) ? $new_instance['access_token'] : '';
		$instance['access_token_secret'] = ( ! empty( $new_instance['access_token_secret'] ) ) ? $new_instance['access_token_secret'] : '';
		$instance['count_tweets'] = ( ! empty( $new_instance['count_tweets'] ) ) ? $new_instance['count_tweets'] : '';

		return $instance;
	}
}

function stm_tweets_widget() {
	register_widget( 'STM_Widget_Tweets' );
}
add_action( 'widgets_init', 'stm_tweets_widget' );